/***************************************************************************
                          positionhistorydlg.h
                             -------------------
    begin                : Sun April 4 2004
    copyright            : (C) 2004 by Elad Lahav
    email                : elad_lahav@users.sf.net
 ***************************************************************************/

#ifndef POSITIONHISTORYDLG_H
#define POSITIONHISTORYDLG_H

#include "positionhistorylayout.h"
#include "positionhistory.h"

/**
 * A modal dialog that displays the position history for the current session.
 * The dialog contains QListView object to display the position history, with 
 * a "File" and "Line" columns.
 * The contents of the dialog are read from the global PositionHistory object.
 * The dialog also allows the user to jump directly to any of the positions
 * displayed.
 * The class inherits PositionListTarget, which allows it use the 
 * PositionHistory::fillList() method.
 * @author Elad Lahav
 */
class PositionHistoryDlg : public PositionHistoryLayout, PositionListTarget
{
	Q_OBJECT

public:
	PositionHistoryDlg(QWidget* pParent = 0, const char* szName = 0);
	~PositionHistoryDlg();

	virtual void addItem(const QString&, uint, int, bool);
	
protected slots:
	virtual void accept();

private:
	/**
	 * Adds an integer data item to QListViewItem.
	 * PositionHistoryDlg uses these list items to store the index of a
	 * position in the PositionHistory object, and thus enables the use of
	 * the PositionHistory::moveTo method.
	 */
	class ListViewItem : public QListViewItem
	{
	public:
		/**
		 * Class constructor.
		 * @param	pList	The list view that holds this item
		 * @param	pAfter	The item after which to insert this one
		 * @param	sLabel1	The text of the first field in the list item
		 * @param	sLabel2	The text of the second field in the list item
		 */
		ListViewItem(QListView* pList, QListViewItem* pAfter, 
			QString sLabel1, QString sLabel2) : 
			QListViewItem(pList, pAfter, sLabel1, sLabel2) {}
		
		/** The index of item in the list. */
		int m_nIndex;
	};
	
	/** Remembers the last added item, so items are appended to the end of the 
		list, maintaining their original order. */
	ListViewItem* m_pItem;

private slots:	
	void slotItemDoubleClicked(QListViewItem*, const QPoint&, int);
};

#endif

